==> JVPC-0.93.zip: JVPC-0.93/vga/Owned.java <==
// File: Owned.java

package jvpc.vga;

import java.util.*;

/**
 * Provides information about the owner and ID of a VGA-Planets object.
 * VGA-Planets is made by Tim Wisseman.
 *
 * <P>Subclasses are: circular, ship and planet.
 *
 * @author    Kero van Gelder
 * @copyright Kero van Gelder (the GNU General Public License applies)
 * @since     10 VII 1998
 * @version   22 V 1999
 */
public abstract class Owned extends Located {
  int id = UNKNOWN;
  int owner = UNKNOWN;

  public Vector getTypes() {
    Vector res = super.getTypes();
    res.addElement("owner");
    res.addElement("id");
    return res;
  }

  public Vector getTypeMethods(String typeName) {
    Vector res = super.getTypeMethods(typeName);
    if ("id".equals(typeName)) {
      res.addElement("getId");
    } else if ("owner".equals(typeName)) {
      res.addElement("getOwner");
    }
    return res;
  }

  public Owned() {}

  public Owned(Universe u) {
    super(u);
  }

  public Owned(Universe u,int id) {
    super(u);
    this.id=id;
  }

  public int getId() {
    return id;
  }

  /**
   * Return the player number of the owner.
   */
  public int getOwner() {
    return owner;
  }

  /**
   * Return the race of the owner
   * See class Race.
   */
  public int getRaceOwner() {
    if (owner == NONE) {
      return NONE;
    } else {
      return getConfig().getPlayerRace(owner);
    }
  }

    public void setOwner(int newOwner) {
       System.err.println(""+this+" -- setOwner("+newOwner+")");
       // planet can not change owner, but can become unowned
       if ((owner == NONE) || (owner == UNKNOWN) || newOwner == NONE) {
           owner = newOwner;
       } else if (newOwner != owner) {
	   crash(11, "changing owner from "+owner+" to "+newOwner);
       }
    }
}

==> JVPC-0.94.zip: JVPC-0.94/vga/Owned.java <==
// File: Owned.java

package jvpc.vga;

import java.util.*;

/**
 * Provides information about the owner and ID of a VGA-Planets object.
 * VGA-Planets is made by Tim Wisseman.
 *
 * <P>Subclasses are: circular, ship and planet.
 *
 * @author    Kero van Gelder
 * @copyright Kero van Gelder (the GNU General Public License applies)
 * @since     10 VII 1998
 * @version   22 V 1999
 */
public abstract class Owned extends Located {
  int id = UNKNOWN;
  int owner = UNKNOWN;

  public Vector getTypes() {
    Vector res = super.getTypes();
    res.addElement("owner");
    res.addElement("id");
    return res;
  }

  public Vector getTypeMethods(String typeName) {
    Vector res = super.getTypeMethods(typeName);
    if ("id".equals(typeName)) {
      res.addElement("getId");
    } else if ("owner".equals(typeName)) {
      res.addElement("getOwner");
    }
    return res;
  }

  public Owned() {}

  public Owned(Universe u) {
    super(u);
  }

  public Owned(Universe u,int id) {
    super(u);
    this.id=id;
  }

  public int getId() {
    return id;
  }

  /**
   * Return the player number of the owner.
   */
  public int getOwner() {
    return owner;
  }

  /**
   * Return the race of the owner
   * See class Race.
   */
  public int getRaceOwner() {
    if (owner == NONE) {
      return NONE;
    } else {
      return getConfig().getPlayerRace(owner);
    }
  }

    public void setOwner(int newOwner) {
       //System.err.println(""+this+" -- setOwner("+newOwner+")");
       // planet can not change owner, but can become unowned
       if ((owner == NONE) || (owner == UNKNOWN) || newOwner == NONE) {
           owner = newOwner;
       } else if (newOwner != owner) {
	   crash(11, "changing owner from "+owner+" to "+newOwner);
       }
    }
}
